@@ -28,7 +28,7 @@ HerculesRMX.jogPlaylistScrollMode = false;
 // quirks. One of which is that the pitch faders are centered at 0x40 instead of
 // 0x3F. If you have a first-generation RMX, set this flag to true to fix things
 // like the pitch control being off by -0.16%. See Bug #863683
-// (https://bugs.launchpad.net/mixxx/+bug/863683).
+// (https://github.com/mixxxdj/mixxx/issues/5999).
 HerculesRMX.firstGenerationFirmware = false;
 
 HerculesRMX.Button = Button;
@@ -39,11 +39,7 @@ HerculesRMX.Button.prototype.setLed = function(ledState, blink) {
     } else {
         midi.sendShortMsg(0xB0,this.controlId,LedState.off);
     }
-    if(blink) {
-       engine.beginTimer(20, "midi.sendShortMsg(0xB0," + (this.controlId + 0x30) + ", " + LedState.on + ")", true);
-    } else {
-       engine.beginTimer(20, "midi.sendShortMsg(0xB0," + (this.controlId + 0x30) + ", " + LedState.off + ")", true);
-    }
+    engine.beginTimer(20, () => midi.sendShortMsg(0xB0, this.controlId, blink ? LedState.on : LedState.off), true);
 };
 
 HerculesRMX.shiftHandler = function(value) {
@@ -821,7 +817,7 @@ HerculesRMX.init = function (id) {    // called when the MIDI device is opened &
 
    engine.connectControl("[Channel1]","rate","HerculesRMX.rateChange");
    engine.connectControl("[Channel2]","rate","HerculesRMX.rateChange");
-   
+
    // Enable soft-takeover for all direct hardware controls
    engine.softTakeover("[Channel1]","rate",true);
    engine.softTakeover("[Channel1]","volume",true);
@@ -856,14 +852,13 @@ HerculesRMX.shutdown = function() {
 HerculesRMX.killLeds = function() {
    HerculesRMX.Buttons.Scratch.setLed(LedState.off);
    //TODO: remove timers when alsa midi work properly.
-   var button;
    var time = 20;
    for (var key in HerculesRMX.Decks.Left.Buttons) {
-      engine.beginTimer(time, "HerculesRMX.Decks.Left.Buttons['" + key + "'].setLed(LedState.off)", true);
+      engine.beginTimer(time, () => HerculesRMX.Decks.Left.Buttons[key].setLed(LedState.off), true);
       time = time + 5;
    }
    for (var key in HerculesRMX.Decks.Right.Buttons) {
-      engine.beginTimer(time, "HerculesRMX.Decks.Right.Buttons['" + key + "'].setLed(LedState.off)", true);
+      engine.beginTimer(time, () => HerculesRMX.Decks.Right.Buttons[key].setLed(LedState.off), true);
       time = time + 5;
    }
 }
@@ -875,11 +870,10 @@ HerculesRMX.rateChange = function (value, group) {
       HerculesRMX.Decks.Left.Buttons.Sync.setLed(LedState.off);
    }
    if (HerculesRMX.Decks.Right.Buttons.Sync.state != ButtonState.pressed) {
-      engine.beginTimer(25, "HerculesRMX.Decks.Right.Buttons.Sync.setLed(LedState.off)", true);
+      engine.beginTimer(25, () => HerculesRMX.Decks.Right.Buttons.Sync.setLed(LedState.off), true);
    }
    if (value != 0.0) {
-      var deck = HerculesRMX.GetDeck(group);
-      engine.beginTimer(30, "HerculesRMX.GetDeck('" + group + "').Buttons.PitchReset.setLed(LedState.off)", true);
+      engine.beginTimer(30, () => HerculesRMX.GetDeck(group).Buttons.PitchReset.setLed(LedState.off), true);
    }
 };
 
@@ -909,12 +903,10 @@ HerculesRMX.rateChange = function (value, group) {
 //   HerculesRMX.stopJog[group] = 1.0;
 //   HerculesRMX.decayLast = new Date().getTime();
 //   engine.setValue(group,"scratch",HerculesRMX.stopJog[group]);
-//   HerculesRMX.stoping = true;
+//   HerculesRMX.stopping = true;
 //   return;
 //      } else {
 //        engine.setValue(group,"playposition",0);
 //      }
 //   }
 //};
-
-
